@@ -126,6 +126,8 @@ class mysql(object):
 		if 'table' in args:
 			self.table=args['table']
 			del args['table']
+		if not args:
+			args=obj(name='mysql')
 		for x in args:
 			connect_config[x]=args[x]
 		self.connect_config = connect_config
